package com.github.gkutiel.flip.mail;

import org.apache.commons.mail.DefaultAuthenticator;
import org.apache.commons.mail.Email;
import org.apache.commons.mail.EmailException;
import org.apache.commons.mail.HtmlEmail;

abstract class Smtp implements EmailProvider {
	protected final String smtpServer;
	protected final String from;
	protected final DefaultAuthenticator authenticator;

	public Smtp(final String smtpServer, final String from, final String password) {
		this.smtpServer = smtpServer;
		this.from = from;
		authenticator = new DefaultAuthenticator(from, password);
	}

	protected abstract void config(Email email);

	protected abstract int port();

	@Override
	public void send(final String subject, final String body, final String... to) {
		try {
			final HtmlEmail email = new HtmlEmail();
			email.setCharset("UTF-8");

			email.setHostName(smtpServer);
			email.setSmtpPort(port());
			email.setAuthenticator(authenticator);

			email.setFrom(from);
			email.setSubject(subject);
			email.setHtmlMsg(body);

			for (final String t : to)
				email.addTo(t);

			config(email);
			email.send();
		} catch (final EmailException e) {
			throw new RuntimeException(e);
		}

	}

}
